@@ -4,7 +4,7 @@ package Test::Class::Moose;
 
 use 5.10.0;
 
-our $VERSION = '0.73';
+our $VERSION = '0.74';
 
 use Moose 2.0000;
 use Carp;
@@ -144,8 +144,8 @@ has '_config_p' => (
 );
 
 sub import {
-    my $class = shift;
-    my %args  = @_;
+    shift;
+    my %args = @_;
 
     my $caller = caller;
 
@@ -244,7 +244,7 @@ sub test_setup    { }
 sub test_teardown { }
 sub test_shutdown { }
 
-sub run_test_shutdown_on_skip {0}
+sub run_control_methods_on_skip {0}
 
 __PACKAGE__->meta->make_immutable;
 
@@ -262,7 +262,7 @@ Test::Class::Moose - Serious testing for serious Perl
 
 =head1 VERSION
 
-version 0.73
+version 0.74
 
 =head1 SYNOPSIS
 
@@ -318,7 +318,7 @@ you get:
 Better docs will come later. You should already know how to use Moose and
 L<Test::Class>.
 
-=for Pod::Coverage Tags Tests runtests run_test_shutdown_on_skip
+=for Pod::Coverage Tags Tests runtests run_control_methods_on_skip
 
 =head1 BASICS
 
@@ -544,8 +544,11 @@ you're about to run, you can do this:
     $test->next::method;
  }
 
-Runs at the end of each test method. This method is always run, even if the
-method was skipped.
+Runs at the end of each test method.
+
+By default, this is not run if the test class is skipped entirely. You can
+override the C<run_control_methods_on_skip> in your class to return a true
+value in order to force this method to be run when the class is skipped.
 
 =head2 C<test_shutdown>
 
@@ -558,8 +561,8 @@ method was skipped.
 Runs at the end of each test class.
 
 By default, this is not run if the test class is skipped entirely. You can
-override the C<run_test_shutdown_on_skip> in your class to return a true value
-in order to force this method to be run when the class is skipped.
+override the C<run_control_methods_on_skip> in your class to return a true
+value in order to force this method to be run when the class is skipped.
 
 =head2 Overriding Test Control Methods
 
